from enum import Enum


class DocumentType(Enum):
    PASSPORT = 'Passport'
    ID = 'ID'
    DL = 'DL'
    RESIDENCE_PERMIT = 'ResidencePermit'
    HEALTH_CARD = 'HealthCard'
    VISA = 'VISA'
    OTHER = 'Other'
